/**************************************************************************
/* Render results as a html-page.
/*
/* Copyright (c) 2003-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This library is free software; you can redistribute it and/or modify
/* it under the terms of the GNU Lesser General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This library is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Lesser General Public License for more details.
/*
/* You should have received a copy of the GNU Lesser General Public License
/* along with this library; see the file COPYING.LESSER.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

package de.bablokb.luala.lib;

import java.io.*;
import org.apache.lucene.search.*;


/**
   Render results as a html-page. The default settings use a very simple
   layout and the {@link StandardDocumentHtmlRenderer} as default values.

   @version $Revision: 1.8 $
   @author  $Author: bablokb $
*/

public class HtmlResultRenderer extends BasicResultRenderer {

  private final static String DEFAULT_HEADER =
"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n" +
"   <html>\n" +
"     <head>\n" +
"       <title>Search-Results</title>\n" +
"     </head>\n" +
"\n" +
"     <body>\n" +
"       <h1>Search-Results</h1>\n\n" +
"         <p><ol>\n";

  private final static String DEFAULT_FOOTER =
"       </ol></p>\n" +
"     </body>\n" +
"  </html>\n";

  ////////////////////////////////////////////////////////////////////////////

  /**
     Constructor. This just sets the header, renderer andfooter fields of the
     base class.

     @param prefix The path-prefix to use
  */

  public HtmlResultRenderer(String prefix) {
    setHeader(DEFAULT_HEADER);
    setFooter(DEFAULT_FOOTER);
    StandardDocumentHtmlRenderer renderer = new StandardDocumentHtmlRenderer();
    renderer.setShowSummary(getShowSummary());
    renderer.setPrefix(prefix);
    setRenderer(renderer);
  }
}
