/**************************************************************************
/* Render results as an array of strings.
/*
/* Copyright (c) 2003-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This library is free software; you can redistribute it and/or modify
/* it under the terms of the GNU Lesser General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This library is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Lesser General Public License for more details.
/*
/* You should have received a copy of the GNU Lesser General Public License
/* along with this library; see the file COPYING.LESSER.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

package de.bablokb.luala.lib;

import java.io.*;
import org.apache.lucene.document.*;


/**
   Render results as an array of strings. The default settings use a very simple
   layout and the {@link StandardDocumentTextRenderer} as default values.

   @version $Revision: 1.5 $
   @author  $Author: bablokb $
*/

public class StringArrayResultRenderer implements ResultRenderer {

  ////////////////////////////////////////////////////////////////////////////

  /**
     The {@link StandardDocumentRenderer} responsible of rendering individual hits.
  */

  private StandardDocumentRenderer iDocumentRenderer;

  ////////////////////////////////////////////////////////////////////////////

  /**
     Constructor. This just saves the prefix.

     @param prefix The path-prefix to use
  */

  public StringArrayResultRenderer(String prefix) {
    iDocumentRenderer = new StandardDocumentTextRenderer();
    iDocumentRenderer.setPrefix(prefix);
    iDocumentRenderer.setShowSummary(false);
  }

  ////////////////////////////////////////////////////////////////////////////

  /**
     {@inheritDoc}
  */

  public Object render(Document[] results) throws IOException {
    String[] retVal = new String[results.length];
    
    for (int i = 0; i < results.length; i++)
      retVal[i] = new String(iDocumentRenderer.render(results[i]));
    return retVal;
  }

}
