/**************************************************************************
/* An event encapsulating a showDocument-request.
/*
/* Copyright (c) 2003-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This library is free software; you can redistribute it and/or modify
/* it under the terms of the GNU Lesser General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This library is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Lesser General Public License for more details.
/*
/* You should have received a copy of the GNU Lesser General Public License
/* along with this library; see the file COPYING.LESSER.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

package de.bablokb.luala.lib.event;

import java.util.*;

/**
   An event encapsulating a showDocument-request.

   @version $Revision: 1.4 $
   @author  $Author: bablokb $
*/

public class ShowDocumentEvent  extends EventObject {

  ////////////////////////////////////////////////////////////////////////////

  /**
     The name of the document to show.
  */

  private String iName;

  ////////////////////////////////////////////////////////////////////////////

  /**
     Auxiliary data.
  */

  private Object iData;

  ////////////////////////////////////////////////////////////////////////////

  /**
     Create a ShowDocumentEvent with the given string.

     @param source The source of the event
     @param name name of the document
  */

  public ShowDocumentEvent(Object source, String name) {
    super(source);
    iName = name;
  }

  ////////////////////////////////////////////////////////////////////////////

  /**
     Set the auxiliary data.

     @param data auxiliary data
  */

  public void setData(Object data) {
    iData = data;
  }

  ////////////////////////////////////////////////////////////////////////////

  /**
     Return the name of the document.

     @return the name of the document
  */

  public String getName() {
    return iName;
  }

  ////////////////////////////////////////////////////////////////////////////

  /**
     Return the auxiliary data of the event.

     @return the auxiliary data of the document
  */

  public Object getData() {
    return iData;
  }
}

