/**************************************************************************
/* Prototyping class for indexing. This is a modified version of
/* src/demo/org/apache/lucene/demo/IndexFiles.java from the Lucene
/* distribution. See COPYING.lucene in the toplevel directory for
/* copyright information about Lucene.
/*
/* Copyright (c) 2003-2004 by Bernhard Bablok (mail@bablokb.de)
/*
/* This library is free software; you can redistribute it and/or modify
/* it under the terms of the GNU Lesser General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This library is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU Lesser General Public License for more details.
/*
/* You should have received a copy of the GNU Lesser General Public License
/* along with this library; see the file COPYING.LESSER.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

package de.bablokb.luala.prototype;

import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.index.IndexWriter;
import org.pdfbox.searchengine.lucene.LucenePDFDocument;

import java.io.File;
import java.util.Date;

/**
   Prototyping class for indexing.

   @version $Revision: 1.4 $
   @author  $Author: bablokb $
*/

public class IndexFiles {

  private FileDocument iFileDocument;

  public IndexFiles() {
    iFileDocument = new FileDocument();
  }

  public static void main(String[] args) {
    try {
      if (args.length != 2) {
	System.out.println("usage: java " + IndexFiles.class.getName() + 
                                                     " srcDir indexDir");
        System.exit(1);
      }
	
      Date start = new Date();

      IndexWriter writer = 
        new IndexWriter(args[1], new StandardAnalyzer(), true);
      IndexFiles indexer = new IndexFiles();
      indexer.indexDocs(writer, new File(args[0]));

      writer.optimize();
      writer.close();

      Date end = new Date();

      System.out.print(end.getTime() - start.getTime());
      System.out.println(" total milliseconds");

    } catch (Exception e) {
      System.out.println(" caught a " + e.getClass() +
			 "\n with message: " + e.getMessage());
    }
  }

  public void indexDocs(IndexWriter writer, File file)
       throws Exception {
    if (file.isDirectory()) {
      String[] files = file.list();
      for (int i = 0; i < files.length; i++)
	indexDocs(writer, new File(file, files[i]));
    } else {
      System.out.println("adding " + file);
      if (file.getName().endsWith(".pdf"))
	writer.addDocument(LucenePDFDocument.getDocument(file));
      else
	writer.addDocument(iFileDocument.createDocument(file));
    }
  }
}
